# Changelog

## v0.2.0
- Pure Python m3gnet without extensions (though some dependencies require extensions).
  This makes it easier to install.

## v0.1.1
- Stress bug fix in molecular potential training

## v0.1.0
- Official first Zenodo release.

## v0.0.9
- More flexible NPT-MD scheme to MolecularDynamics class (@VvVLzy)
- Add early stopping support (@dgaines2)
- Filter warnings for less verbose output (@janosh)

## v0.0.8
- Remove requirement for pymatgen>2022.

## v0.0.7
- Simple CLI tool for relaxing crystals.

## v0.0.6

- Less noisy Relaxer by default.

## v0.0.4

- Fix model download
- More documentation
- Bug fixes

## v0.0.2

- Fix edge cases for triple bonds
- Enable model weights download within code

## v0.0.1

- Initial release.
